@@ -199,7 +199,7 @@ class IMdata:
             
             plt.imshow(data_new,vmin=vmin_now, vmax=vmax_now , 
                             interpolation='nearest',cmap=cmap_now, origin='lower',
-                            extent=(min(xx),max(xx),min(yy),max(yy)))
+                            extent=(min(xx),max(xx),min(yy),max(yy)),**kwargs)
 
             if FWHM:
                 FWHM_thresh=0.5*(np.max(data_new))
